#' 31678 Streptocci, Fecal, Tube Configuration
#'
#' A table containing the USGS Streptocci, Fecal, Tube Configuration parameter
#' codes.
#'
#' @format A data frame with 8 rows and 3 variables:
#' \describe{
#' \item{Parameter Code}{USGS Parameter Code}
#' \item{Fixed Value}{Fixed Value}
#' \item{Fixed Text}{Fixed Text}
#' }
#'
#'
#' @references
#' This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See \url{https://help.waterdata.usgs.gov/codes-and-parameters/}.
#'
#'
#'
#'
"pmcode_31678"
#> [1] "pmcode_31678"
